/*
 * Copyright 2021-2021 Alfresco Software, Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.alfresco.activiti.runtime.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.alfresco.activiti.runtime.model.AnnotatedMemberAnnotated;
import org.alfresco.activiti.runtime.model.AnnotatedMemberMember;
import org.alfresco.activiti.runtime.model.AnnotationMap;
import org.alfresco.activiti.runtime.model.TypeResolutionContext;
import org.springframework.validation.annotation.Validated;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * AnnotatedMember
 */
@Validated


public class AnnotatedMember   {
  @JsonProperty("fullName")
  private String fullName = null;

  @JsonProperty("member")
  private AnnotatedMemberMember member = null;

  @JsonProperty("typeContext")
  private TypeResolutionContext typeContext = null;

  @JsonProperty("allAnnotations")
  private AnnotationMap allAnnotations = null;

  @JsonProperty("name")
  private String name = null;

  @JsonProperty("public")
  private Boolean _public = null;

  @JsonProperty("annotated")
  private AnnotatedMemberAnnotated annotated = null;

  public AnnotatedMember fullName(String fullName) {
    this.fullName = fullName;
    return this;
  }

  /**
   * Get fullName
   * @return fullName
   **/
  @ApiModelProperty(value = "")
  
    public String getFullName() {
    return fullName;
  }

  public void setFullName(String fullName) {
    this.fullName = fullName;
  }

  public AnnotatedMember member(AnnotatedMemberMember member) {
    this.member = member;
    return this;
  }

  /**
   * Get member
   * @return member
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public AnnotatedMemberMember getMember() {
    return member;
  }

  public void setMember(AnnotatedMemberMember member) {
    this.member = member;
  }

  public AnnotatedMember typeContext(TypeResolutionContext typeContext) {
    this.typeContext = typeContext;
    return this;
  }

  /**
   * Get typeContext
   * @return typeContext
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public TypeResolutionContext getTypeContext() {
    return typeContext;
  }

  public void setTypeContext(TypeResolutionContext typeContext) {
    this.typeContext = typeContext;
  }

  public AnnotatedMember allAnnotations(AnnotationMap allAnnotations) {
    this.allAnnotations = allAnnotations;
    return this;
  }

  /**
   * Get allAnnotations
   * @return allAnnotations
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public AnnotationMap getAllAnnotations() {
    return allAnnotations;
  }

  public void setAllAnnotations(AnnotationMap allAnnotations) {
    this.allAnnotations = allAnnotations;
  }

  public AnnotatedMember name(String name) {
    this.name = name;
    return this;
  }

  /**
   * Get name
   * @return name
   **/
  @ApiModelProperty(value = "")
  
    public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public AnnotatedMember _public(Boolean _public) {
    this._public = _public;
    return this;
  }

  /**
   * Get _public
   * @return _public
   **/
  @ApiModelProperty(value = "")
  
    public Boolean isPublic() {
    return _public;
  }

  public void setPublic(Boolean _public) {
    this._public = _public;
  }

  public AnnotatedMember annotated(AnnotatedMemberAnnotated annotated) {
    this.annotated = annotated;
    return this;
  }

  /**
   * Get annotated
   * @return annotated
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public AnnotatedMemberAnnotated getAnnotated() {
    return annotated;
  }

  public void setAnnotated(AnnotatedMemberAnnotated annotated) {
    this.annotated = annotated;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    AnnotatedMember annotatedMember = (AnnotatedMember) o;
    return Objects.equals(this.fullName, annotatedMember.fullName) &&
        Objects.equals(this.member, annotatedMember.member) &&
        Objects.equals(this.typeContext, annotatedMember.typeContext) &&
        Objects.equals(this.allAnnotations, annotatedMember.allAnnotations) &&
        Objects.equals(this.name, annotatedMember.name) &&
        Objects.equals(this._public, annotatedMember._public) &&
        Objects.equals(this.annotated, annotatedMember.annotated);
  }

  @Override
  public int hashCode() {
    return Objects.hash(fullName, member, typeContext, allAnnotations, name, _public, annotated);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class AnnotatedMember {\n");
    
    sb.append("    fullName: ").append(toIndentedString(fullName)).append("\n");
    sb.append("    member: ").append(toIndentedString(member)).append("\n");
    sb.append("    typeContext: ").append(toIndentedString(typeContext)).append("\n");
    sb.append("    allAnnotations: ").append(toIndentedString(allAnnotations)).append("\n");
    sb.append("    name: ").append(toIndentedString(name)).append("\n");
    sb.append("    _public: ").append(toIndentedString(_public)).append("\n");
    sb.append("    annotated: ").append(toIndentedString(annotated)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
