/*
 * Copyright 2021-2021 Alfresco Software, Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.alfresco.activiti.runtime.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.ArrayList;
import java.util.List;
import org.alfresco.activiti.runtime.model.VariableDefinition;
import org.springframework.validation.annotation.Validated;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * ExtendedCloudProcessDefinition
 */
@Validated


public class ExtendedCloudProcessDefinition   {
  @JsonProperty("variableDefinitions")
  @Valid
  private List<VariableDefinition> variableDefinitions = null;

  @JsonProperty("serviceName")
  private String serviceName = null;

  @JsonProperty("serviceFullName")
  private String serviceFullName = null;

  @JsonProperty("serviceType")
  private String serviceType = null;

  @JsonProperty("serviceVersion")
  private String serviceVersion = null;

  @JsonProperty("appName")
  private String appName = null;

  @JsonProperty("appVersion")
  private String appVersion = null;

  @JsonProperty("version")
  private Integer version = null;

  @JsonProperty("name")
  private String name = null;

  @JsonProperty("key")
  private String key = null;

  @JsonProperty("id")
  private String id = null;

  @JsonProperty("description")
  private String description = null;

  @JsonProperty("category")
  private String category = null;

  @JsonProperty("formKey")
  private String formKey = null;

  public ExtendedCloudProcessDefinition variableDefinitions(List<VariableDefinition> variableDefinitions) {
    this.variableDefinitions = variableDefinitions;
    return this;
  }

  public ExtendedCloudProcessDefinition addVariableDefinitionsItem(VariableDefinition variableDefinitionsItem) {
    if (this.variableDefinitions == null) {
      this.variableDefinitions = new ArrayList<>();
    }
    this.variableDefinitions.add(variableDefinitionsItem);
    return this;
  }

  /**
   * Get variableDefinitions
   * @return variableDefinitions
   **/
  @ApiModelProperty(value = "")
      @Valid
    public List<VariableDefinition> getVariableDefinitions() {
    return variableDefinitions;
  }

  public void setVariableDefinitions(List<VariableDefinition> variableDefinitions) {
    this.variableDefinitions = variableDefinitions;
  }

  public ExtendedCloudProcessDefinition serviceName(String serviceName) {
    this.serviceName = serviceName;
    return this;
  }

  /**
   * Get serviceName
   * @return serviceName
   **/
  @ApiModelProperty(value = "")
  
    public String getServiceName() {
    return serviceName;
  }

  public void setServiceName(String serviceName) {
    this.serviceName = serviceName;
  }

  public ExtendedCloudProcessDefinition serviceFullName(String serviceFullName) {
    this.serviceFullName = serviceFullName;
    return this;
  }

  /**
   * Get serviceFullName
   * @return serviceFullName
   **/
  @ApiModelProperty(value = "")
  
    public String getServiceFullName() {
    return serviceFullName;
  }

  public void setServiceFullName(String serviceFullName) {
    this.serviceFullName = serviceFullName;
  }

  public ExtendedCloudProcessDefinition serviceType(String serviceType) {
    this.serviceType = serviceType;
    return this;
  }

  /**
   * Get serviceType
   * @return serviceType
   **/
  @ApiModelProperty(value = "")
  
    public String getServiceType() {
    return serviceType;
  }

  public void setServiceType(String serviceType) {
    this.serviceType = serviceType;
  }

  public ExtendedCloudProcessDefinition serviceVersion(String serviceVersion) {
    this.serviceVersion = serviceVersion;
    return this;
  }

  /**
   * Get serviceVersion
   * @return serviceVersion
   **/
  @ApiModelProperty(value = "")
  
    public String getServiceVersion() {
    return serviceVersion;
  }

  public void setServiceVersion(String serviceVersion) {
    this.serviceVersion = serviceVersion;
  }

  public ExtendedCloudProcessDefinition appName(String appName) {
    this.appName = appName;
    return this;
  }

  /**
   * Get appName
   * @return appName
   **/
  @ApiModelProperty(value = "")
  
    public String getAppName() {
    return appName;
  }

  public void setAppName(String appName) {
    this.appName = appName;
  }

  public ExtendedCloudProcessDefinition appVersion(String appVersion) {
    this.appVersion = appVersion;
    return this;
  }

  /**
   * Get appVersion
   * @return appVersion
   **/
  @ApiModelProperty(value = "")
  
    public String getAppVersion() {
    return appVersion;
  }

  public void setAppVersion(String appVersion) {
    this.appVersion = appVersion;
  }

  public ExtendedCloudProcessDefinition version(Integer version) {
    this.version = version;
    return this;
  }

  /**
   * Get version
   * @return version
   **/
  @ApiModelProperty(value = "")
  
    public Integer getVersion() {
    return version;
  }

  public void setVersion(Integer version) {
    this.version = version;
  }

  public ExtendedCloudProcessDefinition name(String name) {
    this.name = name;
    return this;
  }

  /**
   * Get name
   * @return name
   **/
  @ApiModelProperty(value = "")
  
    public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public ExtendedCloudProcessDefinition key(String key) {
    this.key = key;
    return this;
  }

  /**
   * Get key
   * @return key
   **/
  @ApiModelProperty(value = "")
  
    public String getKey() {
    return key;
  }

  public void setKey(String key) {
    this.key = key;
  }

  public ExtendedCloudProcessDefinition id(String id) {
    this.id = id;
    return this;
  }

  /**
   * Get id
   * @return id
   **/
  @ApiModelProperty(value = "")
  
    public String getId() {
    return id;
  }

  public void setId(String id) {
    this.id = id;
  }

  public ExtendedCloudProcessDefinition description(String description) {
    this.description = description;
    return this;
  }

  /**
   * Get description
   * @return description
   **/
  @ApiModelProperty(value = "")
  
    public String getDescription() {
    return description;
  }

  public void setDescription(String description) {
    this.description = description;
  }

  public ExtendedCloudProcessDefinition category(String category) {
    this.category = category;
    return this;
  }

  /**
   * Get category
   * @return category
   **/
  @ApiModelProperty(value = "")
  
    public String getCategory() {
    return category;
  }

  public void setCategory(String category) {
    this.category = category;
  }

  public ExtendedCloudProcessDefinition formKey(String formKey) {
    this.formKey = formKey;
    return this;
  }

  /**
   * Get formKey
   * @return formKey
   **/
  @ApiModelProperty(value = "")
  
    public String getFormKey() {
    return formKey;
  }

  public void setFormKey(String formKey) {
    this.formKey = formKey;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    ExtendedCloudProcessDefinition extendedCloudProcessDefinition = (ExtendedCloudProcessDefinition) o;
    return Objects.equals(this.variableDefinitions, extendedCloudProcessDefinition.variableDefinitions) &&
        Objects.equals(this.serviceName, extendedCloudProcessDefinition.serviceName) &&
        Objects.equals(this.serviceFullName, extendedCloudProcessDefinition.serviceFullName) &&
        Objects.equals(this.serviceType, extendedCloudProcessDefinition.serviceType) &&
        Objects.equals(this.serviceVersion, extendedCloudProcessDefinition.serviceVersion) &&
        Objects.equals(this.appName, extendedCloudProcessDefinition.appName) &&
        Objects.equals(this.appVersion, extendedCloudProcessDefinition.appVersion) &&
        Objects.equals(this.version, extendedCloudProcessDefinition.version) &&
        Objects.equals(this.name, extendedCloudProcessDefinition.name) &&
        Objects.equals(this.key, extendedCloudProcessDefinition.key) &&
        Objects.equals(this.id, extendedCloudProcessDefinition.id) &&
        Objects.equals(this.description, extendedCloudProcessDefinition.description) &&
        Objects.equals(this.category, extendedCloudProcessDefinition.category) &&
        Objects.equals(this.formKey, extendedCloudProcessDefinition.formKey);
  }

  @Override
  public int hashCode() {
    return Objects.hash(variableDefinitions, serviceName, serviceFullName, serviceType, serviceVersion, appName, appVersion, version, name, key, id, description, category, formKey);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class ExtendedCloudProcessDefinition {\n");
    
    sb.append("    variableDefinitions: ").append(toIndentedString(variableDefinitions)).append("\n");
    sb.append("    serviceName: ").append(toIndentedString(serviceName)).append("\n");
    sb.append("    serviceFullName: ").append(toIndentedString(serviceFullName)).append("\n");
    sb.append("    serviceType: ").append(toIndentedString(serviceType)).append("\n");
    sb.append("    serviceVersion: ").append(toIndentedString(serviceVersion)).append("\n");
    sb.append("    appName: ").append(toIndentedString(appName)).append("\n");
    sb.append("    appVersion: ").append(toIndentedString(appVersion)).append("\n");
    sb.append("    version: ").append(toIndentedString(version)).append("\n");
    sb.append("    name: ").append(toIndentedString(name)).append("\n");
    sb.append("    key: ").append(toIndentedString(key)).append("\n");
    sb.append("    id: ").append(toIndentedString(id)).append("\n");
    sb.append("    description: ").append(toIndentedString(description)).append("\n");
    sb.append("    category: ").append(toIndentedString(category)).append("\n");
    sb.append("    formKey: ").append(toIndentedString(formKey)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
