/*
 * Copyright 2021-2021 Alfresco Software, Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.alfresco.activiti.runtime.model;

import java.util.Objects;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import org.alfresco.activiti.runtime.model.JsonDeserializerObject;
import org.alfresco.activiti.runtime.model.ObjectIdGeneratorObject;
import org.alfresco.activiti.runtime.model.ObjectIdResolver;
import org.alfresco.activiti.runtime.model.PropertyName;
import org.alfresco.activiti.runtime.model.SettableBeanProperty;
import org.springframework.validation.annotation.Validated;
import javax.validation.Valid;
import javax.validation.constraints.*;

/**
 * ObjectIdReader
 */
@Validated


public class ObjectIdReader   {
  @JsonProperty("propertyName")
  private PropertyName propertyName = null;

  @JsonProperty("generator")
  private ObjectIdGeneratorObject generator = null;

  @JsonProperty("resolver")
  private ObjectIdResolver resolver = null;

  @JsonProperty("idProperty")
  private SettableBeanProperty idProperty = null;

  @JsonProperty("deserializer")
  private JsonDeserializerObject deserializer = null;

  public ObjectIdReader propertyName(PropertyName propertyName) {
    this.propertyName = propertyName;
    return this;
  }

  /**
   * Get propertyName
   * @return propertyName
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public PropertyName getPropertyName() {
    return propertyName;
  }

  public void setPropertyName(PropertyName propertyName) {
    this.propertyName = propertyName;
  }

  public ObjectIdReader generator(ObjectIdGeneratorObject generator) {
    this.generator = generator;
    return this;
  }

  /**
   * Get generator
   * @return generator
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public ObjectIdGeneratorObject getGenerator() {
    return generator;
  }

  public void setGenerator(ObjectIdGeneratorObject generator) {
    this.generator = generator;
  }

  public ObjectIdReader resolver(ObjectIdResolver resolver) {
    this.resolver = resolver;
    return this;
  }

  /**
   * Get resolver
   * @return resolver
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public ObjectIdResolver getResolver() {
    return resolver;
  }

  public void setResolver(ObjectIdResolver resolver) {
    this.resolver = resolver;
  }

  public ObjectIdReader idProperty(SettableBeanProperty idProperty) {
    this.idProperty = idProperty;
    return this;
  }

  /**
   * Get idProperty
   * @return idProperty
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public SettableBeanProperty getIdProperty() {
    return idProperty;
  }

  public void setIdProperty(SettableBeanProperty idProperty) {
    this.idProperty = idProperty;
  }

  public ObjectIdReader deserializer(JsonDeserializerObject deserializer) {
    this.deserializer = deserializer;
    return this;
  }

  /**
   * Get deserializer
   * @return deserializer
   **/
  @ApiModelProperty(value = "")
  
    @Valid
    public JsonDeserializerObject getDeserializer() {
    return deserializer;
  }

  public void setDeserializer(JsonDeserializerObject deserializer) {
    this.deserializer = deserializer;
  }


  @Override
  public boolean equals(java.lang.Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    ObjectIdReader objectIdReader = (ObjectIdReader) o;
    return Objects.equals(this.propertyName, objectIdReader.propertyName) &&
        Objects.equals(this.generator, objectIdReader.generator) &&
        Objects.equals(this.resolver, objectIdReader.resolver) &&
        Objects.equals(this.idProperty, objectIdReader.idProperty) &&
        Objects.equals(this.deserializer, objectIdReader.deserializer);
  }

  @Override
  public int hashCode() {
    return Objects.hash(propertyName, generator, resolver, idProperty, deserializer);
  }

  @Override
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("class ObjectIdReader {\n");
    
    sb.append("    propertyName: ").append(toIndentedString(propertyName)).append("\n");
    sb.append("    generator: ").append(toIndentedString(generator)).append("\n");
    sb.append("    resolver: ").append(toIndentedString(resolver)).append("\n");
    sb.append("    idProperty: ").append(toIndentedString(idProperty)).append("\n");
    sb.append("    deserializer: ").append(toIndentedString(deserializer)).append("\n");
    sb.append("}");
    return sb.toString();
  }

  /**
   * Convert the given object to string with each line indented by 4 spaces
   * (except the first line).
   */
  private String toIndentedString(java.lang.Object o) {
    if (o == null) {
      return "null";
    }
    return o.toString().replace("\n", "\n    ");
  }
}
